
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.2.15'
version = '1.2.15'
full_version = '1.2.15'
git_revision = '2c203d8fc96701632574893b14622c619f374b53'
release = True

if not release:
    version = full_version
    short_version += ".dev"
